==> huaweicloudsdkosm-3.0.50-py2.py3-none-any.whl: huaweicloudsdkosm/v2/model/list_relation_response.py <==
# coding: utf-8

import pprint
import re

import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class ListRelationResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'case_relation_list': 'list[CaseRealtionInfo]'
    }

    attribute_map = {
        'case_relation_list': 'case_relation_list'
    }

    def __init__(self, case_relation_list=None):
        """ListRelationResponse - a model defined in huaweicloud sdk"""
        
        super(ListRelationResponse, self).__init__()

        self._case_relation_list = None
        self.discriminator = None

        if case_relation_list is not None:
            self.case_relation_list = case_relation_list

    @property
    def case_relation_list(self):
        """Gets the case_relation_list of this ListRelationResponse.

        关联工单列表

        :return: The case_relation_list of this ListRelationResponse.
        :rtype: list[CaseRealtionInfo]
        """
        return self._case_relation_list

    @case_relation_list.setter
    def case_relation_list(self, case_relation_list):
        """Sets the case_relation_list of this ListRelationResponse.

        关联工单列表

        :param case_relation_list: The case_relation_list of this ListRelationResponse.
        :type: list[CaseRealtionInfo]
        """
        self._case_relation_list = case_relation_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListRelationResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkosm-3.0.51-py2.py3-none-any.whl: huaweicloudsdkosm/v2/model/list_relation_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class ListRelationResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'case_relation_list': 'list[CaseRealtionInfo]'
    }

    attribute_map = {
        'case_relation_list': 'case_relation_list'
    }

    def __init__(self, case_relation_list=None):
        """ListRelationResponse - a model defined in huaweicloud sdk"""
        
        super(ListRelationResponse, self).__init__()

        self._case_relation_list = None
        self.discriminator = None

        if case_relation_list is not None:
            self.case_relation_list = case_relation_list

    @property
    def case_relation_list(self):
        """Gets the case_relation_list of this ListRelationResponse.

        关联工单列表

        :return: The case_relation_list of this ListRelationResponse.
        :rtype: list[CaseRealtionInfo]
        """
        return self._case_relation_list

    @case_relation_list.setter
    def case_relation_list(self, case_relation_list):
        """Sets the case_relation_list of this ListRelationResponse.

        关联工单列表

        :param case_relation_list: The case_relation_list of this ListRelationResponse.
        :type: list[CaseRealtionInfo]
        """
        self._case_relation_list = case_relation_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListRelationResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
